benchmarkResults: Results from running a performance benchmark on a personal...

benchmarkResultsR Documentation

Results from running a performance benchmark on a personal computer including the time for parameter transformation

Description

Results from running a performance benchmark on a personal computer including the time for parameter transformation

Usage

benchmarkResults

Format

A data.table


PCMBaseCpp documentation built on March 1, 2026, 1:07 a.m.