benchmarkResultsNoTransform: Results from running a performance benchmark on a personal...

benchmarkResultsNoTransformR Documentation

Results from running a performance benchmark on a personal computer excluding the time for parameter transformation

Description

Results from running a performance benchmark on a personal computer excluding the time for parameter transformation

Usage

benchmarkResultsNoTransform

Format

A data.table


PCMBaseCpp documentation built on March 1, 2026, 1:07 a.m.